<?php
namespace App\modele;

use App\gateway\Connection;
use App\gateway\EvenementGateway;
use App\metier\Evenement;

class UtilisateurModele

{
    private $con;

    public function __construct()
    {
        $this->con = new Connection(DB_HOST,DB_USER,DB_PASS);
    }

    /**
     * @description se connecter
     * @param string email
     * @param string hash
     * @return \App\metier\Alumni
     */

     public function connection(string $email, string $mdp) : ? \App\metier\Alumni
     {
         $con = new \App\gateway\Connection(DB_HOST,DB_USER,DB_PASS);
         $gate = new \App\gateway\AlumniGateway($con);
         // Récupérez l'utilisateur avec l'email donné en utilisant AlumniGateway
         $utilisateur = $gate->findByEmail($email);
         if ($utilisateur instanceof \App\metier\Alumni) {
             // L'utilisateur existe, vérifiez le mot de passe
             if (password_verify($mdp, $utilisateur->getPassword())) {
                 // Le mot de passe est correct, retournez l'utilisateur
                 session_start();
                 return $utilisateur;
             } else {
                 // Le mot de passe est incorrect, renvoyez null
                 return null;
             }
         } else {
             // L'utilisateur n'existe pas, renvoyez null
             return null;
         }
     } 

    /**
     * @description s'inscrire
     * @param string email
     * @param string hash
     * @param string $pseudo
     * @return \Alumni chargé
     */

     public function inscription(string $prenom, string $nom,string $email, string $hashpassword):? \App\metier\Alumni
     {
         $role = "Membre";
         $con = new \App\gateway\Connection(DB_HOST,DB_USER,DB_PASS);
         $gate = new \App\gateway\AlumniGateway($con);
         $profilGate = new \App\gateway\ProfilGateway($con);
         // Insérez le nouvel utilisateur dans la base de données en utilisant AlumniGateway
         if ($gate->insert($email, $hashpassword, $role)) {
             $alumni = $gate->getID($email);
             if($profilGate->insert($alumni,$nom, $prenom,$email)){
                 // L'insertion a réussi, retournez le nouvel utilisateur
                 $nouvelUtilisateur = new \App\metier\Alumni($email, $hashpassword, $role,$nom,$prenom);
                 return $nouvelUtilisateur;
             }
             return null;
         } else {
             // L'insertion a échoué, renvoyez un utilisateur vide pour indiquer l'échec
             return null;
         }
     }
 
     public function getUtilisateurByEmail(string $email) 
     {
         $con = new \App\gateway\Connection(DB_HOST,DB_USER,DB_PASS);
         $gate = new \App\gateway\AlumniGateway($con);
         // Récupérez l'utilisateur avec l'email donné en utilisant AlumniGateway
         $utilisateur = $gate->findByEmail($email);
         if ($utilisateur instanceof \App\metier\Alumni) {
             // L'utilisateur existe, retournez-le
             return $utilisateur;
         } else {
             // L'utilisateur n'existe pas, renvoyez null
             return null;
         }
     }

    public function getEvenement() : array 
    {
        $gate = new EvenementGateway($this->con);

        $data = $gate->getAllEvenement();

        $evenement = array();

        foreach($data as $row)
        {
            $evenement[] = new Evenement(
                $row['id'],
                $row['organisateur'],
                $row['titre'],
                $row['description'],
                $row['date'],
                $row['nbPlaceMax'],
                $row['image']
            );
        }
        return $evenement;
    }

    public function ajouterEvenement(string $titre, string $description, string $date, int $nbPlaceMax, string $img)
    {
        $gate = new EvenementGateway($this->con);

        $evenement = new Evenement(
            $gate->getNewId(),
            '1', //TODO : Ajouter l'ID de l'admin connecté
            $titre,
            $description,
            $date,
            $nbPlaceMax,
            $img
        );

        $gate->insertEvenement($evenement);
    }

    public function deleteEvenement(int $id)
    {
        $gate = new EvenementGateway($this->con);
        $gate->deleteEvenement($id);
    }

    public function getEvenementById(int $id) : Evenement
    {
        $gate = new EvenementGateway($this->con); 

        $data = $gate->findById($id);

        $evenement = new Evenement(
            $data[0]['id'],
            $data[0]['organisateur'],
            $data[0]['titre'],
            $data[0]['description'],
            $data[0]['date'],
            $data[0]['nbPlaceMax'],
            $data[0]['image']
        );

        return $evenement;
    }

    public function getEvenementByTitre(string $titre) : array
    {
        $gate = new EvenementGateway($this->con); 

        $data = $gate->findByTitle($titre);

        $evenement = array();

        foreach($data as $row)
        {
            $evenement[] = new Evenement(
                $row['id'],
                $row['organisateur'],
                $row['titre'],
                $row['description'],
                $row['date'],
                $row['nbPlaceMax'],
                $row['image']
            );
        }

        return $evenement;
    }
}